'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = _interopDefault(require('prop-types'));

var parseGooglePlace = function parseGooglePlace() {
  var place = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var byType = placeAttrsByType(place.address_components);
  var getter = placeGet(byType);

  return {
    address: [getter('street_number'), getter('route')].join(' ').trim(),
    streetNumber: getter('street_number'),
    streetName: getter('route'),
    city: getter('locality') || getter('sublocality') || getter('sublocality_level_1') || getter('neighborhood') || getter('administrative_area_level_3') || getter('administrative_area_level_2'),
    county: getter('administrative_area_level_2'),
    stateShort: getter('administrative_area_level_1', true),
    stateLong: getter('administrative_area_level_1'),
    countryShort: getter('country', true),
    countryLong: getter('country'),
    zipCode: getter('postal_code')
  };
};

var intervalSetAutocomplete = function intervalSetAutocomplete(elem) {
  if (!window.chrome) return;
  elem.setAttribute('autocomplete', 'nope');
  return setInterval(function () {
    elem.setAttribute('autocomplete', 'nope');
  }, 1500);
};

var placeAttrsByType = function placeAttrsByType(addrComponents) {
  return (addrComponents || []).reduce(function (acc, data) {
    data.types.forEach(function (type) {
      acc[type] = data;
    });
    return acc;
  }, {});
};

var placeGet = function placeGet(byType) {
  return function (key, short) {
    if (!(key in byType)) return '';

    return short ? byType[key].short_name : byType[key].long_name;
  };
};

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var objectWithoutProperties = function (obj, keys) {
  var target = {};

  for (var i in obj) {
    if (keys.indexOf(i) >= 0) continue;
    if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
    target[i] = obj[i];
  }

  return target;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var Autocomplete = function (_Component) {
  inherits(Autocomplete, _Component);

  function Autocomplete() {
    classCallCheck(this, Autocomplete);
    return possibleConstructorReturn(this, (Autocomplete.__proto__ || Object.getPrototypeOf(Autocomplete)).apply(this, arguments));
  }

  createClass(Autocomplete, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      var _this2 = this;

      var _props = this.props,
          fields = _props.fields,
          id = _props.id,
          onPlaceChanged = _props.onPlaceChanged,
          types = _props.types;


      var elem = document.getElementById(id);
      this.autocomplete = new window['google'].maps.places.Autocomplete(elem, {
        types: types,
        componentRestrictions: {
          country: 'us'
        }
      });

      this.autocomplete.setFields(fields);

      this.autocomplete.addListener('place_changed', function () {
        var place = _this2.autocomplete.getPlace();
        onPlaceChanged({ original: place, parsed: parseGooglePlace(place) });
      });

      // Yeah, this sucks. There is no way to know when Google Autcomplete
      // finishes loading. We also need to keep resetting the autocomplete
      // value since they keep setting it to "off". We need it to be something
      // else to actually turn autocomplete offa
      this.autocompleteInterval = intervalSetAutocomplete(elem);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      clearInterval(this.autocompleteInterval);
    }
  }, {
    key: 'render',
    value: function render() {
      var _props2 = this.props,
          fields = _props2.fields,
          onPlaceChanged = _props2.onPlaceChanged,
          rest = objectWithoutProperties(_props2, ['fields', 'onPlaceChanged']);

      var inputAutoComplete = window.chrome ? 'nope' : 'off';
      return React__default.createElement('input', _extends({ type: 'text', autoComplete: inputAutoComplete }, rest));
    }
  }]);
  return Autocomplete;
}(React.Component);

Autocomplete.propTypes = {
  className: PropTypes.string,
  fields: PropTypes.arrayOf(PropTypes.string).isRequired,
  id: PropTypes.string.isRequired,
  onPlaceChanged: PropTypes.func.isRequired,
  style: PropTypes.object,
  types: PropTypes.arrayOf(PropTypes.string).isRequired
};

Autocomplete.defaultProps = {
  fields: ['address_components', 'formatted_address', 'place_id'],
  onPlaceChanged: function onPlaceChanged(place) {
    console.log('This is a placeholder function for the `onPlaceChanged` prop. You should override this.');
    console.log(place);
  },
  types: ['address']
};

var SearchBox = function (_Component) {
  inherits(SearchBox, _Component);

  function SearchBox() {
    classCallCheck(this, SearchBox);
    return possibleConstructorReturn(this, (SearchBox.__proto__ || Object.getPrototypeOf(SearchBox)).apply(this, arguments));
  }

  createClass(SearchBox, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      var _this2 = this;

      var _props = this.props,
          id = _props.id,
          onPlaceChanged = _props.onPlaceChanged;


      this.searchbox = new window['google'].maps.places.SearchBox(document.getElementById(id), {});

      this.searchbox.addListener('places_changed', function () {
        var places = _this2.searchbox.getPlaces();
        onPlaceChanged({ original: places, parsed: places.map(parseGooglePlace) });
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var _props2 = this.props,
          fields = _props2.fields,
          onPlaceChanged = _props2.onPlaceChanged,
          rest = objectWithoutProperties(_props2, ['fields', 'onPlaceChanged']);

      return React__default.createElement('input', _extends({ type: 'text' }, rest));
    }
  }]);
  return SearchBox;
}(React.Component);

SearchBox.propTypes = {
  className: PropTypes.string,
  id: PropTypes.string.isRequired,
  onPlaceChanged: PropTypes.func.isRequired,
  style: PropTypes.object
};

SearchBox.defaultProps = {
  onPlaceChanged: function onPlaceChanged(place) {
    console.log('This is a placeholder function for the `onPlaceChanged` prop. You should override this.');
    console.log(place);
  }
};

exports.Autocomplete = Autocomplete;
exports.SearchBox = SearchBox;
//# sourceMappingURL=index.js.map
